<?php

namespace Drupal\entity_workflow_content\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\workspaces\Form\WorkspaceSwitcherForm;
use Drupal\wse\Form\WseWorkspaceSwitcherForm;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Allows users to choose a workspace on pages that require one.
 */
class WorkspaceSwitcherController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a WorkspaceSwitcherController object.
   *
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(FormBuilderInterface $form_builder) {
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('form_builder')
    );
  }

  /**
   * Provides the workspace switcher form.
   */
  public function switcher(Request $request) {
    if ($this->moduleHandler()->moduleExists('wse')
        && $this->config('wse.settings')->get('simplified_toolbar_switcher')) {
      $switcher_form = WseWorkspaceSwitcherForm::class;
    }
    else {
      $switcher_form = WorkspaceSwitcherForm::class;
    }

    $form = $this->formBuilder->getForm($switcher_form);

    // Hide form elements that are irrelevant for this switcher.
    if ($switcher_form === WseWorkspaceSwitcherForm::class) {
      $form['workspace_status']['#access'] = FALSE;
    }
    else {
      $form['current']['#access'] = FALSE;
    }

    return [
      '#markup' => $this->t('This action can only be done inside a workspace. Choose one below.'),
      'form' => $form,
    ];
  }

  /**
   * Provides the closed workspace controller.
   */
  public function closed(): array {
    return [
      '#markup' => $this->t('This workspace is closed, its content can no longer be edited.'),
    ];
  }

  /**
   * Provides the locked workspace controller.
   */
  public function locked(): array {
    return [
      '#markup' => $this->t('This workspace is in a locked state, its content can not be edited.'),
    ];
  }

}
