<?php

namespace Drupal\entity_workflow_workspace\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\workspaces\WorkspaceManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates the LockedWorkspace constraint.
 */
class LockedWorkspaceConstraintValidator extends ConstraintValidator implements ContainerInjectionInterface {

  public function __construct(
    protected readonly WorkspaceManagerInterface $workspaceManager
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('workspaces.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validate($entity, Constraint $constraint) {
    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    if (isset($entity) && !$entity->isNew()) {
      $active_workspace = $this->workspaceManager->getActiveWorkspace();

      if ($active_workspace) {
        $field = entity_workflow_get_field($active_workspace, 'workspace');
        if ($state_id = $field->getStateId()) {
          /** @var \Drupal\entity_workflow_workspace\WorkspaceState $state */
          $state = $field->getWorkflow()->getTypePlugin()->getState($state_id);

          if ($state->isLocked()) {
            $this->context->buildViolation($constraint->message)
              ->setParameter('%label', $active_workspace->label())
              ->addViolation();
          }
        }
      }
    }
  }

}
