<?php

declare(strict_types = 1);

namespace Drupal\entity_workflow_workspace;

use Drupal\entity_workflow\EntityWorkflowState;
use Drupal\workflows\StateInterface;
use Drupal\workflows\WorkflowTypeInterface;

/**
 * A value object representing a workflow state for Entity Workflow.
 */
class WorkspaceState extends EntityWorkflowState implements StateInterface {

  /**
   * Whether content can be edited in this state.
   */
  protected bool $locked;

  /**
   * The workspace status to set when reaching this state.
   */
  protected string $status;

  /**
   * {@inheritdoc}
   */
  public function __construct(WorkflowTypeInterface $workflow, $id, array $configuration) {
    parent::__construct($workflow, $id, $configuration);

    $this->locked = (bool) ($configuration['locked'] ?? FALSE);
    $this->status = $configuration['status'] ?? WSE_STATUS_OPEN;
  }

  /**
   * Whether content can be edited in this state.
   */
  public function isLocked(): bool {
    return $this->locked;
  }

  /**
   * The workspace status to set when reaching this state.
   */
  public function getStatus(): string {
    return $this->status;
  }

}
