<?php

namespace Drupal\entity_workflow\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\workflows\TransitionInterface;
use Drupal\workflows\WorkflowInterface;

/**
 * Defines the base class for entity workflow transition events.
 */
abstract class EntityWorkflowTransitionEvent extends Event {

  /**
   * The transition.
   *
   * @var \Drupal\workflows\TransitionInterface
   */
  protected $transition;

  /**
   * The workflow.
   *
   * @var \Drupal\workflows\WorkflowInterface
   */
  protected $workflow;

  /**
   * The entity.
   *
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  protected $entity;

  /**
   * The state field name.
   *
   * @var string
   */
  protected $fieldName;

  /**
   * The transition context.
   *
   * @var array
   */
  protected $context;

  /**
   * Constructs a new EntityWorkflowTransitionEvent object.
   *
   * @param \Drupal\workflows\TransitionInterface $transition
   *   The transition.
   * @param \Drupal\workflows\WorkflowInterface $workflow
   *   The workflow.
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity.
   * @param string $field_name
   *   The state field name.
   * @param array $context
   *   The transition context.
   */
  public function __construct(TransitionInterface $transition, WorkflowInterface $workflow, ContentEntityInterface $entity, $field_name, array $context = []) {
    $this->transition = $transition;
    $this->workflow = $workflow;
    $this->entity = $entity;
    $this->fieldName = $field_name;
    $this->context = $context;
  }

  /**
   * Gets the transition.
   *
   * @return \Drupal\workflows\TransitionInterface
   *   The transition.
   */
  public function getTransition() {
    return $this->transition;
  }

  /**
   * Gets the workflow.
   *
   * @return \Drupal\workflows\WorkflowInterface
   *   The workflow.
   */
  public function getWorkflow() {
    return $this->workflow;
  }

  /**
   * Gets the entity.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The entity.
   */
  public function getEntity() {
    return $this->entity;
  }

  /**
   * Gets the state field name.
   *
   * @return string
   *   The state field name.
   */
  public function getFieldName() {
    return $this->fieldName;
  }

  /**
   * Gets the state field.
   *
   * @return \Drupal\entity_workflow\EntityWorkflowStateItemInterface
   *   The state field.
   */
  public function getField() {
    return entity_workflow_get_field($this->entity, $this->workflow->id());
  }

  /**
   * Gets the transition context.
   *
   * @return array
   *   The transition context.
   */
  public function getContext() {
    return $this->context;
  }

}
