<?php

namespace Drupal\entity_workflow\Form;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\workflows\Plugin\WorkflowTypeConfigureFormBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The entity workflow WorkflowType configuration form.
 *
 * @see \Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeBase
 */
class EntityWorkflowConfigureForm extends WorkflowTypeConfigureFormBase implements ContainerInjectionInterface {

  /**
   * Constructor.
   */
  public function __construct(
    protected readonly EntityTypeManagerInterface $entityTypeManager,
    protected readonly EntityTypeBundleInfoInterface $entityTypeBundleInfo
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_type.bundle.info')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeInterface $workflow_plugin */
    $workflow = $form_state->getFormObject()->getEntity();
    $workflow_plugin = $workflow->getTypePlugin();

    // Display the list of entity types and bundles that this workflow applies to.
    $header = [
      'entity_type' => t('Entity type'),
      'bundles' => t('Bundles'),
    ];
    $form['entity_types_container'] = [
      '#type' => 'details',
      '#title' => t('This workflow applies to:'),
      '#open' => TRUE,
    ];
    $form['entity_types_container']['entity_types'] = [
      '#type' => 'table',
      '#header' => $header,
      '#empty' => t('There are no entity types.'),
    ];

    $entity_types = $this->entityTypeManager->getDefinitions();
    foreach ($workflow_plugin->getEntityTypes() as $entity_type_id) {
      $selected_bundles = [];
      foreach ($this->entityTypeBundleInfo->getBundleInfo($entity_type_id) as $bundle_id => $bundle) {
        if ($workflow_plugin->appliesToEntityTypeAndBundle($entity_type_id, $bundle_id)) {
          $selected_bundles[$bundle_id] = $bundle['label'];
        }
      }
      $form['entity_types_container']['entity_types'][$entity_type_id] = [
        'entity_type' => [
          '#markup' => $entity_types[$entity_type_id]->getLabel(),
        ],
        'bundles' => [
          '#theme' => 'item_list',
          '#items' => $selected_bundles,
          '#context' => ['list_style' => 'comma-list'],
          '#empty' => t('none'),
        ],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    // Nothing to do here.
  }

}
