<?php

namespace Drupal\entity_workflow\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\workflows\Plugin\WorkflowTypeTransitionFormBase;

/**
 * Form to configure entity workflow transitions.
 */
class EntityWorkflowTransitionForm extends WorkflowTypeTransitionFormBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\entity_workflow\EntityWorkflowTransition $transition */
    $transition = $form_state->get('transition');

    $element = [];
    $element['action_link'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Action link'),
      '#description' => $this->t('Whether to provide an action link for this transition.'),
      '#default_value' => isset($transition) ? $transition->hasActionLink() : TRUE,
    ];

    $element['transition_log'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log'),
      '#description' => $this->t('Whether to provide a transition log for this transition.'),
      '#default_value' => isset($transition) ? $transition->hasLog() : TRUE,
    ];
    $element['transition_log_required'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log required'),
      '#description' => $this->t('Whether the transition log should be required.'),
      '#default_value' => isset($transition) ? $transition->isLogRequired() : FALSE,
      '#states' => [
        'visible' => [
          ':input[name="type_settings[transition_log]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return $element;
  }

}
