<?php

namespace Drupal\entity_workflow;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;

/**
 * Defines the storage handler class for workflow transition logs.
 */
class WorkflowTransitionLogStorage extends SqlContentEntityStorage {

  /**
   * Writes a log entry directly in the base table.
   *
   * @param \Drupal\Core\Entity\FieldableEntityInterface $entity
   * @param $workflow_id
   * @param $previous_state
   * @param $new_state
   * @param $transition_id
   * @param $log
   *
   * @return void
   */
  public function writeLogEntry(FieldableEntityInterface $entity, $workflow_id, $previous_state, $new_state, $transition_id, $log) {
    $id_field = $entity->getFieldDefinition($entity->getEntityType()->getKey('id'));
    $source_entity_id = $id_field->getType() === 'integer' ? 'entity_id' : 'entity_id_string';
    if ($entity->getEntityTypeId() === 'workspace') {
      $workspace_id = $entity->id();
    }
    else {
      $field_name = $entity->getEntityType()->getRevisionMetadataKey('workspace');
      $workspace_id = !$entity->get($field_name)->isEmpty() ? $entity->get($field_name)->target_id : \Drupal::service('workspaces.manager')->getActiveWorkspace()->id();
    }

    $record = [
      'workflow_id' => $workflow_id,
      'workspace_id' => $workspace_id,
      'entity_type_id' => $entity->getEntityTypeId(),
      $source_entity_id => $entity->id(),
      'entity_revision_id' => $entity->getRevisionId(),
      'state' => $new_state,
      'transition' => $transition_id,
      'previous_state' => $previous_state,
      'log' => $log,
      'uid' => \Drupal::currentUser()->id(),
      'created' => \Drupal::service('datetime.time')->getCurrentTime(),
    ];

    $this->database
      ->insert($this->baseTable)
      ->fields($record)
      ->execute();

    Cache::invalidateTags(['workflow_transition_log_list']);
  }

}
