<?php

namespace Drupal\entity_workflow\WorkflowType;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\entity_workflow\EntityWorkflowInfo;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides dynamic permissions for entity workflows.
 */
class Permissions implements ContainerInjectionInterface {

  /**
   * The entity workflow information service.
   *
   * @var \Drupal\entity_workflow\EntityWorkflowInfo
   */
  protected $entityWorkflowInfo;

  /**
   * Constructs a new Permissions instance.
   *
   * @param \Drupal\entity_workflow\EntityWorkflowInfo $entity_workflow_info
   *   The entity workflow information service.
   */
  public function __construct(EntityWorkflowInfo $entity_workflow_info) {
    $this->entityWorkflowInfo = $entity_workflow_info;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_workflow.info')
    );
  }

  /**
   * Returns an array of permissions.
   *
   * @return array
   *   The permissions for all entity workflows.
   */
  public function getPermissions() {
    $perms = [];

    // Generate permissions for all entity workflows that provide them.
    foreach ($this->entityWorkflowInfo->getWorkflowEntities() as $workflow) {
      /** @var \Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeInterface $workflow_type */
      $workflow_type = $workflow->getTypePlugin();

      if ($permissions = $workflow_type->getPermissions()) {
        foreach ($permissions as $id => $permission) {
          $permission += ['provider' => $workflow_type->getPluginDefinition()['provider']];
          $perms[$id] = $permission;
        }
      }
    }

    return $perms;
  }

}
